@@ -22,6 +22,7 @@ import math
 import re
 import unicodedata
 
+import pyparsing as pp
 import six
 from six.moves import urllib
 
@@ -110,11 +111,14 @@ def int_from_bool_as_string(subject):
 
 
 def bool_from_string(subject, strict=False, default=False):
-    """Interpret a string as a boolean.
+    """Interpret a subject as a boolean.
 
-    A case-insensitive match is performed such that strings matching 't',
-    'true', 'on', 'y', 'yes', or '1' are considered True and, when
-    `strict=False`, anything else returns the value specified by 'default'.
+    A subject can be a boolean, a string or an integer. Boolean type value
+    will be returned directly, otherwise the subject will be converted to
+    a string. A case-insensitive match is performed such that strings
+    matching 't','true', 'on', 'y', 'yes', or '1' are considered True and,
+    when `strict=False`, anything else returns the value specified by
+    'default'.
 
     Useful for JSON-decoded stuff and config file parsing.
 
@@ -144,6 +148,19 @@ def bool_from_string(subject, strict=False, default=False):
         return default
 
 
+def is_valid_boolstr(value):
+    """Check if the provided string is a valid bool string or not.
+
+    :param value: value to verify
+    :type value: string
+    :returns: true if value is boolean string, false otherwise
+
+    .. versionadded:: 3.17
+    """
+    boolstrs = TRUE_STRINGS + FALSE_STRINGS
+    return str(value).lower() in boolstrs
+
+
 def string_to_bytes(text, unit_system='IEC', return_int=False):
     """Converts a string into an float representation of bytes.
 
@@ -468,3 +485,20 @@ def split_path(path, minsegs=1, maxsegs=None, rest_with_last=False):
     segs = segs[1:maxsegs]
     segs.extend([None] * (maxsegs - 1 - len(segs)))
     return segs
+
+
+def split_by_commas(value):
+    """Split values by commas and quotes according to api-wg
+
+    :param value: value to be split
+
+    .. versionadded:: 3.17
+    """
+    word = (pp.QuotedString(quoteChar='"', escChar='\\')
+            | pp.Word(pp.printables, excludeChars='",'))
+    grammar = pp.stringStart + pp.delimitedList(word) + pp.stringEnd
+
+    try:
+        return list(grammar.parseString(value))
+    except pp.ParseException:
+        raise ValueError("Invalid value: %s" % value)
